use egui_winit_vulkano::egui::ahash::HashMap;
use winit::{
    event::{ElementState, WindowEvent},
    keyboard::PhysicalKey,
};

use super::{process_new_element_state, virtual_input::VirtualInput};

#[derive(Debug, Default)]
pub struct KeyboardState {
    key_states: HashMap<PhysicalKey, ElementState>,
}

impl KeyboardState {
    pub fn process_window_event(&mut self, event: &WindowEvent, virtual_input: &mut VirtualInput) {
        if let WindowEvent::KeyboardInput { event, .. } = event {
            let key_state = self.key_states.get(&event.physical_key);
            let new_key_state = process_new_element_state(key_state, event.state);
            if let Some(new_key_state) = new_key_state {
                self.key_states.insert(event.physical_key, new_key_state);
                virtual_input.update_key_binding(event.physical_key, new_key_state);
            }
        }
    }
}
